"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var recorder_exports = {};
__export(recorder_exports, {
  AudioRecorder: () => AudioRecorder
});
module.exports = __toCommonJS(recorder_exports);
var import_utils = require("./utils.js");
class AudioRecorder {
  constructor(options = {}) {
    this.options = options;
  }
  static async listDevices() {
    return navigator.mediaDevices.enumerateDevices().then((list) => list.filter((d) => d.kind === "audioinput"));
  }
  context;
  listeners = {};
  buffer = [];
  recorder;
  stream;
  async start(deviceId) {
    this.recorder = await this.createAudioRecorder();
    this.recorder.start();
  }
  async stop() {
    return new Promise((resolve) => {
      this.recorder?.addEventListener("stop", () => {
        resolve(this.flush());
      });
      this.recorder?.stop();
      void this.context?.suspend();
      for (const track of this.stream?.getTracks() ?? []) {
        track.stop();
      }
    });
  }
  async installWorklet(name, path, callback) {
    const context = this.getAudioContext();
    const stream = await this.getAudioStream();
    await context.audioWorklet.addModule(path);
    const node = new AudioWorkletNode(context, name);
    await callback({ context, stream, node });
  }
  on(eventName, callback) {
    if (!this.listeners[eventName]) {
      this.listeners[eventName] = [];
    }
    this.listeners[eventName]?.push(callback);
  }
  flush() {
    const blob = new Blob(this.buffer);
    this.buffer = [];
    return blob;
  }
  async createAudioRecorder() {
    const stream = await this.getAudioStream();
    const recorder = new MediaRecorder(stream, this.options);
    if ("volumechange" in this.listeners) {
      await this.setupAudioMeter();
    }
    recorder.addEventListener("dataavailable", ({ data }) => {
      if (data.size > 0) {
        this.buffer?.push(data);
      }
    });
    return recorder;
  }
  fireEvent(name, event) {
    for (const listener of this.listeners?.[name] ?? []) {
      listener(event);
    }
  }
  async getAudioStream() {
    if (!this.stream) {
      this.stream = await (0, import_utils.getUserMedia)();
    }
    return this.stream;
  }
  getAudioContext() {
    if (!this.context) {
      this.context = new AudioContext();
    }
    return this.context;
  }
  getWorkletPath(name) {
    return [this.options.workletPath ?? "worklets", name].join("/");
  }
  async setupAudioMeter() {
    return this.installWorklet(
      "volume-meter",
      this.getWorkletPath("video-meter.js"),
      ({ node, context, stream }) => {
        const micNode = context.createMediaStreamSource(stream);
        node.port.addEventListener(
          "message",
          ({ data: volume }) => {
            this.fireEvent("volumechange", { volume });
          }
        );
        micNode.connect(node).connect(context.destination);
      }
    );
  }
}
//# sourceMappingURL=recorder.js.map
