"use strict";
const smoothingFactor = 0.8;
const framePerSecond = 60;
const frameInterval = 1 / framePerSecond;
class VolumeMeter extends AudioWorkletProcessor {
  lastUpdate = currentTime;
  volume = 0;
  calculateRms(inputChannelData) {
    let sum = 0;
    for (const inputChannelDatum of inputChannelData) {
      sum += inputChannelDatum * inputChannelDatum;
    }
    const rms = Math.sqrt(sum / inputChannelData.length);
    this.volume = Math.max(rms, this.volume * smoothingFactor);
  }
  process(inputs, outputs) {
    const inputChannelData = inputs[0][0];
    if (currentTime - this.lastUpdate > frameInterval) {
      this.calculateRms(inputChannelData);
      this.port.postMessage(this.volume);
      this.lastUpdate = currentTime;
    }
    return true;
  }
}
registerProcessor("volume-meter", VolumeMeter);
//# sourceMappingURL=volume-meter.js.map
